package ru.ulstu.extractor.assessment.service;

import org.springframework.stereotype.Service;
import ru.ulstu.extractor.assessment.model.Assessment;
import ru.ulstu.extractor.rule.model.DbRule;
import ru.ulstu.extractor.rule.service.AntecedentValueService;
import ru.ulstu.extractor.rule.service.DbRuleService;
import ru.ulstu.extractor.rule.service.FuzzyInferenceService;
import ru.ulstu.extractor.ts.model.TimeSeries;
import ru.ulstu.extractor.ts.service.TimeSeriesService;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class AssessmentService {
    private final DbRuleService ruleService;
    private final AntecedentValueService antecedentValueService;
    private final TimeSeriesService timeSeriesService;
    private final FuzzyInferenceService fuzzyInferenceService;

    public AssessmentService(DbRuleService ruleService,
                             AntecedentValueService antecedentValueService,
                             TimeSeriesService timeSeriesService,
                             FuzzyInferenceService fuzzyInferenceService) {
        this.ruleService = ruleService;
        this.antecedentValueService = antecedentValueService;
        this.timeSeriesService = timeSeriesService;
        this.fuzzyInferenceService = fuzzyInferenceService;
    }

    public List<Assessment> getAssessments(Integer branchId) {
        List<TimeSeries> timeSeries = timeSeriesService.getByBranch(branchId);
        List<DbRule> dbRules = ruleService.getList();
        Map<String, Double> variableValues = new HashMap<>();
        timeSeries.forEach(ts -> variableValues.put(ts.getTimeSeriesType().name(), timeSeriesService.getLastTimeSeriesTendency(ts)));
        return fuzzyInferenceService.getFuzzyInference(dbRules,
                antecedentValueService.getList(),
                variableValues);
    }
}
