package ru.ulstu.extractor.ts.service;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;
import ru.ulstu.extractor.branch.model.Branch;
import ru.ulstu.extractor.branch.service.BranchService;
import ru.ulstu.extractor.ts.creator.scheduled.ScheduledTimeSeriesCreator;

import java.util.List;

@Service
public class ScheduledTimeSeriesService {
    private final Logger log = LoggerFactory.getLogger(ScheduledTimeSeriesService.class);
    private final List<ScheduledTimeSeriesCreator> scheduledTimeSeriesCreators;
    private final BranchService branchService;

    public ScheduledTimeSeriesService(List<ScheduledTimeSeriesCreator> scheduledTimeSeriesCreators,
                                      BranchService branchService) {
        this.scheduledTimeSeriesCreators = scheduledTimeSeriesCreators;
        this.branchService = branchService;
    }

    @Scheduled(cron = "0 0 8 * * *", zone = "Europe/Samara")
    public void addTimeSeriesPoints() {
        log.debug("Старт добавления новых точек временного ряда");
        List<Branch> branches = branchService.findAll();
        branches.forEach(branch -> {
            scheduledTimeSeriesCreators.forEach(creator -> creator.addTimeSeriesValue(branch));
        });
        log.debug("Завершение добавления новых точек временного ряда");
    }
}
